#include <unistd.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <limits.h>

namespace WFR // Wave File Reader
{
	double Length;
	unsigned int num_samples;
	int low_limit	= 0l;
	int high_limit	= 0l;
	int BUF[2][2000005];
	int channels;
	struct HEADER
	{
		unsigned char	riff[4];                /* RIFF string */
		unsigned int	overall_size;           /* overall size of file in bytes */
		unsigned char	wave[4];                /* WAVE string */
		unsigned char	fmt_chunk_marker[4];    /* fmt string with trailing null char */
		unsigned int	length_of_fmt;          /* length of the format data */
		unsigned int	format_type;            /* format type. 1-PCM, 3- IEEE float, 6 - 8bit A law, 7 - 8bit mu law */
		unsigned int	channels;               /* no.of channels */
		unsigned int	sample_rate;            /* sampling rate (blocks per second) */
		unsigned int	byterate;               /* SampleRate * NumChannels * BitsPerSample/8 */
		unsigned int	block_align;            /* NumChannels * BitsPerSample/8 */
		unsigned int	bits_per_sample;        /* bits per sample, 8- 8bits, 16- 16 bits etc */
		unsigned char	data_chunk_header [4];  /* DATA string or FLLR string */
		unsigned int	data_size;              /* NumSamples * NumChannels * BitsPerSample/8 - size of the next chunk that will be read */
	};
	unsigned char	buffer4[4];
	unsigned char	buffer2[2];
	struct HEADER header;
	
	void Read()
	{
		int read = 0;
		/* read header parts */
		read = fread( header.riff, sizeof(header.riff), 1, stdin );
		read = fread( buffer4, sizeof(buffer4), 1, stdin );
		/* convert little endian to big endian 4 byte int */
		header.overall_size = buffer4[0] | (buffer4[1] << 8) | (buffer4[2] << 16) | (buffer4[3] << 24);
		read = fread( header.wave, sizeof(header.wave), 1, stdin );
		read = fread( header.fmt_chunk_marker, sizeof(header.fmt_chunk_marker), 1, stdin );
		read = fread( buffer4, sizeof(buffer4), 1, stdin );
		/* convert little endian to big endian 4 byte integer */
		header.length_of_fmt = buffer4[0] | (buffer4[1] << 8) | (buffer4[2] << 16) | (buffer4[3] << 24);
		read = fread( buffer2, sizeof(buffer2), 1, stdin );
		header.format_type = buffer2[0] | (buffer2[1] << 8);
		read = fread( buffer2, sizeof(buffer2), 1, stdin );
		channels = header.channels = buffer2[0] | (buffer2[1] << 8);
		read = fread( buffer4, sizeof(buffer4), 1, stdin );
		header.sample_rate = buffer4[0] | (buffer4[1] << 8) | (buffer4[2] << 16) | (buffer4[3] << 24);
		read = fread( buffer4, sizeof(buffer4), 1, stdin );
		header.byterate = buffer4[0] | (buffer4[1] << 8) | (buffer4[2] << 16) | (buffer4[3] << 24);
		read = fread( buffer2, sizeof(buffer2), 1, stdin );
		header.block_align = buffer2[0] | (buffer2[1] << 8);
		read = fread( buffer2, sizeof(buffer2), 1, stdin );
		header.bits_per_sample = buffer2[0] | (buffer2[1] << 8);
		read = fread( header.data_chunk_header, sizeof(header.data_chunk_header), 1, stdin );
		read = fread( buffer4, sizeof(buffer4), 1, stdin );
		header.data_size = buffer4[0] | (buffer4[1] << 8) | (buffer4[2] << 16) | (buffer4[3] << 24);
		/* calculate no.of samples */
		num_samples = (8 * header.data_size) / (header.channels * header.bits_per_sample);
		int size_of_each_sample = (header.channels * header.bits_per_sample) / 8;
		/* calculate duration of file */
		Length = (float) header.overall_size / header.byterate;
		/* read each sample from data chunk if PCM */
		if ( header.format_type == 1 ) /* PCM */
		{
			int i = 0, size_is_correct = 1;
			char	data_buffer[size_of_each_sample];
			/* make sure that the bytes-per-sample is completely divisible by num.of channels */
			int bytes_in_each_channel = (size_of_each_sample / header.channels);
			if ( size_is_correct )
			{
				/* the valid amplitude range for values based on the bits per sample */
				switch ( header.bits_per_sample )
				{
					case 8:
						low_limit	= CHAR_MIN;
						high_limit	= CHAR_MAX;
						break;
					case 16:
						low_limit	= SHRT_MIN;
						high_limit	= SHRT_MAX;
						break;
					case 32:
						low_limit	= INT_MIN;
						high_limit	= INT_MAX;
						break;
				}
				for ( i = 1; i <= num_samples; i++ )
				{
					read = fread( data_buffer, sizeof(data_buffer), 1, stdin );
					if ( read == 1 )
					{
						/* dump the data read */
						unsigned int	xchannels	= 0;
						int		data_in_channel = 0;
						for ( xchannels = 0; xchannels < header.channels; xchannels++ )
						{
							/* convert data from little endian to big endian based on bytes in each channel sample */
							if ( bytes_in_each_channel == 4 )
							{
								data_in_channel = data_buffer[0] |
										  (data_buffer[1] << 8) |
										  (data_buffer[2] << 16) |
										  (data_buffer[3] << 24);
							}
							else if ( bytes_in_each_channel == 2 )
							{
								data_in_channel = data_buffer[0] |
										  (data_buffer[1] << 8);
							}
							else if ( bytes_in_each_channel == 1 )
							{
								data_in_channel = data_buffer[0];
							}
							BUF[xchannels][i] = data_in_channel;
							/* check if value was in range */
							if ( data_in_channel < low_limit || data_in_channel > high_limit )
								printf( "**value out of range\n" );
						}
					}
					else
					{
						printf( "Error reading file. %d bytes\n", read );
						break;
					}
				}       /*      for (i =1; i <= num_samples; i++) { */
			}               /*      if (size_is_correct) { */
		}                       /*  if (header.format_type == 1) { */
		else puts( "Your Wave File isn't in PCM Format!" );
	}
}

#include <bits/stdc++.h>

#define NS (2000005)
#define PI (3.14159265358979323846)

using namespace std;

typedef complex<double> cpx;

int n, rev[NS * 3];

double data[NS], rate;

cpx d[NS * 3];

void FFT(cpx (&a)[NS * 3], int N, int bs, int f)
{
	for (int i = 1; i < N; i += 1)
		rev[i] = (rev[i >> 1] >> 1) | ((i & 1) << (bs - 1));
	for (int i = 0; i < N; i += 1)
		if (i < rev[i]) swap(a[rev[i]], a[i]);
	for (int l = 1; l < N; l <<= 1)
	{
		cpx w0(cos(PI / l), sin(PI / l) * f);
		for (int i = 0; i < N; i += (l << 1))
		{
			cpx wn(1, 0), t1, t2;
			for (int j = i; j < i + l; j += 1, wn *= w0)
				t1 = a[j], t2 = wn * a[j + l], a[j] = t1 + t2, a[j + l] = t1 - t2;
		}
	}
	if (f == -1) for (int i = 0; i < N; i += 1) a[i] /= N;
}

double mus[NS];

int cnt = 0;

int main(int argc, char const* argv[])
{
	freopen("wave.in", "rb", stdin), freopen("wave.out", "w", stdout);
	WFR::Read(), n = WFR::num_samples, rate = 1.0 * n / WFR::Length;
	for (int i = 1; i <= n; i += 1)
	{
		for (int j = 0; j < WFR::channels; j += 1) data[i] += WFR::BUF[j][i];
		data[i] /= (double)WFR::channels;
	}
	double mx_voc = *max_element(data + 1, data + 1 + n);
	for (int i = 1; i <= n; i += 1)
		if (data[i] < 0.1 * mx_voc)
			data[i] = 0;
	#define STEP 100
	int sz = rate * STEP / 1000;
	int N = 1, bs = 0; while (N <= sz) N <<= 1, bs++;
	for (int i = 1; i + sz - 1 <= n; i += sz)
	{
		for (int j = 0; j < N; j += 1) d[j] = cpx(0, 0);
		for (int j = i; j <= i + sz - 1; j += 1) d[j - i + 1].real(data[j]);
		FFT(d, N, bs, 1);
		double mx = 0, sum = 0, tot = 0; int mi = 0;
		for (int j = 1; j <= (N >> 1); j += 1)
		{
			if (rate * j / N <= 200) continue;
			sum += sqrt(norm(d[j])), tot++;
			if (sqrt(norm(d[j])) > mx)
				mx = sqrt(norm(d[j])), mi = j;
		}
		if (mx < sum / tot * 5) mus[++cnt] = 0;
		else mus[++cnt] = rate * mi / N;
	}
	for (int i = 3; i <= cnt; i += 1)
		if (abs(mus[i] - mus[i - 2]) <= 10 && mus[i] > 1e-4)
			mus[i - 1] = mus[i];
	for (int i = 1; i <= cnt;)
	{
		double F = mus[i]; int sum = STEP; i++;
		while (i <= cnt && (abs(mus[i] - F) <= 10 || mus[i] < 1e-4))
		{
			if (mus[i] < 1e-4) mus[i] = F;
			sum += STEP, F = (mus[i] + F) * 0.5, i++;
		}
		printf("%d %d\n", (int)F, sum);
	}
	return 0;
}
